@@ -7,7 +7,7 @@ use Text::ASCIITable;
 
 extends 'App::Sandy::CLI::Command';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 has 'db' => (
 	is         => 'ro',
@@ -68,7 +68,7 @@ App::Sandy::Command::Quality - quality command class. Manage quality profile dat
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -104,6 +104,14 @@ J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
+Felipe R. C. dos Santos <fsantos@mochsl.org.br>
+
+=item *
+
+Helena B. Conceição <hconceicao@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
