@@ -6,7 +6,7 @@ use Pod::Usage;
 
 extends 'App::Sandy::CLI::Command';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 sub validate_args {
 	my ($self, $args) = @_;
@@ -29,7 +29,7 @@ App::Sandy::Command::Version - version command class. Print version
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 AUTHORS
 
@@ -45,6 +45,14 @@ J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
+Felipe R. C. dos Santos <fsantos@mochsl.org.br>
+
+=item *
+
+Helena B. Conceição <hconceicao@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
