@@ -6,7 +6,7 @@ use App::Sandy::DB::Schema;
 use MooseX::Singleton;
 use Path::Class 'file';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 has 'schema' => (
 	is         => 'ro',
@@ -63,7 +63,7 @@ App::Sandy::DB - Singleton class to manage database
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 AUTHORS
 
@@ -79,6 +79,14 @@ J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
+Felipe R. C. dos Santos <fsantos@mochsl.org.br>
+
+=item *
+
+Helena B. Conceição <hconceicao@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
