@@ -3,7 +3,7 @@ package App::Sandy::InterlaceProcesses;
 
 use App::Sandy::Base 'class';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 has 'foreign_pid' => (
 	is       => 'ro',
@@ -53,7 +53,7 @@ App::Sandy::InterlaceProcesses - Interlaces the processe id for differents proce
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 AUTHORS
 
@@ -69,6 +69,14 @@ J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
+Felipe R. C. dos Santos <fsantos@mochsl.org.br>
+
+=item *
+
+Helena B. Conceição <hconceicao@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
