@@ -9,7 +9,7 @@ extends 'App::Sandy::Read';
 
 with 'App::Sandy::Role::RNorm';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 has 'fragment_mean' => (
 	is       => 'ro',
@@ -88,7 +88,7 @@ App::Sandy::Read::PairedEnd - App::Sandy::Read subclass for simulate paired-end
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 AUTHORS
 
@@ -104,6 +104,14 @@ J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
+Felipe R. C. dos Santos <fsantos@mochsl.org.br>
+
+=item *
+
+Helena B. Conceição <hconceicao@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
