@@ -5,7 +5,7 @@ use App::Sandy::Base 'class';
 
 with 'App::Sandy::Role::BSearch';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 has 'keys' => (
 	traits     => ['Array'],
@@ -129,7 +129,7 @@ App::Sandy::WeightedRaffle - Weighted raffle interface.
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 AUTHORS
 
@@ -145,6 +145,14 @@ J. Leonel Buzzo <lbuzzo@mochsl.org.br>
 
 =item *
 
+Felipe R. C. dos Santos <fsantos@mochsl.org.br>
+
+=item *
+
+Helena B. Conceição <hconceicao@mochsl.org.br>
+
+=item *
+
 Gabriela Guardia <gguardia@mochsl.org.br>
 
 =item *
